@@ -9,8 +9,7 @@ from pydantic import BaseModel as _BaseModel
 import numpy as np
 import pandas as pd
 from fastapi import HTTPException, Depends
-from datetime import datetime
-
+from datetime import datetime, timedelta
 
 import time
 import pathlib
@@ -19,6 +18,7 @@ import requests
 import subprocess
 
 
+
 class BaseHandler:
 
     dtype_sample = {
@@ -31,7 +31,7 @@ class BaseHandler:
         "object": "?"
     }
 
-    def __init__(self, server,  m, model_version):
+    def __init__(self, server,  m, model_version, check=True):
         # parent server
         self.server = server
 
@@ -62,16 +62,20 @@ class BaseHandler:
         metadata = _Model.load(os.path.join(
             self.model_folder, mlflow.pyfunc.MLMODEL_FILE_NAME))
 
-        health = False
-        checkcount = False
-        while health == False and checkcount < 5:
-            health = self.health()
-            checkcount += 1
-            time.sleep(1.0)
+        self._health_expired = datetime.now()
+        self._health_last = False
 
-        if health == False:
-            self._stop_server()
-            raise Exception("Model not working with example input!")
+        if check:
+            health = False
+            checkcount = False
+            while health == False and checkcount < 5:
+                health = self.health()
+                checkcount += 1
+                time.sleep(1.0)
+
+            if health == False:
+                self._stop_server()
+                raise Exception("Model not working with example input!")
 
         try:
             input_schema = metadata.get_input_schema()
@@ -287,10 +291,25 @@ class BaseHandler:
         """
         stop the mlflow server
         """
+        try:
+            self.__serve_logfile.error("Start Kill server")
+        except:
+            pass
+
+
         try:
             self.__serve_proc.kill()
         except:
             pass
+
+
+
+        try:
+            self.__serve_proc.kill()
+        except:
+            pass
+
+
         try:
             self.__serve_logfile.error("Killed server")
         except:
@@ -302,12 +321,20 @@ class BaseHandler:
 
         Uses the input example to compute a result.
         """
+        current_time = datetime.now()
+
+        if current_time < self._health_expired:
+            return self._health_last
+
         inp = self._get_input_example()
 
         try:
             res = self._predict(inp)
+            self._health_expired = datetime.now() + timedelta(minutes=10)
+            self._health_last = res.ok
             return res.ok
         except:
+            self._health_last = False
             return False
 
     def _predict(self, inp):
@@ -315,8 +342,7 @@ class BaseHandler:
         Just call the created server to compute the result
         """
         self.__serve_logfile.info(inp)
-        res = requests.post(
-            f"http://localhost:{self.port}/invocations", json=inp)
+        res = requests.post(f"http://localhost:{self.port}/invocations", json=inp, stream=True)
         if res.ok:
             self.__serve_logfile.info("OK")
         else:
@@ -471,12 +497,13 @@ class BaseHandler:
             raise self._get_error_message(
                 "Model prediction error", _MlflowException(res.json()["message"]))
 
-        try:
-            output = self._parse_output(model_output)
-        except Exception as ex:
-            raise self._get_error_message("Parse output error", ex)
+        return model_output
 
-        return output
+        # try:
+        #     output = self._parse_output(model_output)
+        # except Exception as ex:
+        #     raise self._get_error_message("Parse output error", ex)
+        # return output
 
     def _get_version_link(self, name, model_version):
         return f"{model_version.version}"
